@@ -139,8 +139,16 @@ class MainFrameRes(QtGui.QWidget):
                                                len(table.head[0]), self)
 
         if not hasattr (self, 'mytable'):
-            self.mytable = SelectedTableWidget(len(table.body[0]), \
-                                  len(table.head[0]), self, readonly = True)
+            if table.body:
+                len_body = len(table.body[0])
+            else:
+                len_body = 1
+            if table.head:
+                len_head = len(table.head[0])
+            else:
+                len_head = 1
+            self.mytable = SelectedTableWidget(len_body, len_head, self,
+                                                   readonly = True)
         list_head = table.head[0]
         self.mytable.setHorizontalHeaderLabels(list_head)
         for line in range(len(table.body[0])):
@@ -826,4 +834,4 @@ class MessageDialog(QtGui.QWidget):
         if self.pass_edit.text() != self.pass_edit2.text():
             self.send_button.setDisabled(True)
         else:
-            self.send_button.setEnabled(True)
\ No newline at end of file
+            self.send_button.setEnabled(True)
